/**
 * WooCommerce specific js functions
 */
(function($) { 'use strict';

	var w=window,d=document,
	e=d.documentElement,
	g=d.getElementsByTagName('body')[0];

	// Custom input number field

	function customNumInput(){

	 var inputNum = $('input.input-text.qty');

		if(inputNum.length){
			inputNum.each(function(){
				var thisInput = $(this);

				thisInput.parent('.quantity').append('<a id="up" href="#">+</a><a id="down" href="#">-</a>');
				var adjustVal = thisInput.siblings('a');

				adjustVal.on('click', function(e){
					var minVal = parseInt(thisInput.attr('min'));
					var maxVal = parseInt(thisInput.attr('max'));
					e.preventDefault();
					var $this = $(this);
					var value = parseInt(thisInput.val());
					if (isNaN(minVal)){
						minVal = 0;
					}

					if (isNaN(maxVal)){
						maxVal = Number.MAX_VALUE;
					}

					if ($this.is('#down') && (value > minVal)){
						value--;
					}
					else if ($this.is('#up') && (value < maxVal)){
						value++;
					}
					thisInput.val(value);

					$(this).parents('form').find('button[name=update_cart]').prop("disabled", false);
				});
			});
		}
	}

	$( document.body ).on( 'updated_cart_totals', function() {
		customNumInput();
	} );

	$(document).ready(function($){

		// Calculate clients viewport

		var x=w.innerWidth||e.clientWidth||g.clientWidth, // Viewport Width
		y=w.innerHeight||e.clientHeight||g.clientHeight; // Viewport Height

		// Global vars

		var $window = $(window);
		var body = $('body');

		// Custom input number field

		customNumInput();

		// Popup widget area

		var popupWidgetArea = $('.popup-widgets #secondary');

		if(body.hasClass('popup-widgets')){
			var widgetAreaTrig = $('#widget-area-trig');

			var closePopupSidebarFn = function(){
				if(body.hasClass('popup-opened')){
					body.removeClass('popup-opened');
				}
			};


			popupWidgetArea.on('touchend click', function(e){
				e.stopPropagation();
			});

			if(x > 1024){
				widgetAreaTrig.on('touchend click', function (e){
					e.stopPropagation();
					body.toggleClass('popup-opened');
				});

				$(document).on('touchend click', function(){
					closePopupSidebarFn();
				});

				$(document).keyup(function(e) {
					if (e.keyCode == 27) {
						closePopupSidebarFn();
					}
				});
			}
			else{
				var sidebar = $('#secondary');
				var widgetAreaTrigOffsetTop = widgetAreaTrig.offset().top;

				sidebar.prepend('<i class="icon-close"></i>');

				sidebar.find('i.icon-close').on('touchend click', function (){
					closePopupSidebarFn();
				});

				widgetAreaTrig.on('click', function (e){
					e.stopPropagation();
					body.toggleClass('popup-opened');
					$('html, body').animate({scrollTop: widgetAreaTrigOffsetTop}, 800, 'swing');
				});
			}

		}

		// Split layout on product single

		if(body.hasClass('half-width-slider')){

			$('div.images, div.summary, span.onsale').wrapAll('<div class="split-layout"></div>');

			var slider = $('figure.woocommerce-product-gallery__wrapper');
			var sliderImg = slider.find('img');

			if(sliderImg.length){
				sliderImg.each(function(){
					var $this = $(this);
					var slideImgSrc;

					if ($this.attr('data-lazy-src')){
						slideImgSrc = $this.attr('data-lazy-src');
					}
					else{
						slideImgSrc = $this.attr('src');
					}
					$this.closest('.woocommerce-product-gallery__image').css({backgroundImage: 'url('+slideImgSrc+')'});
				});
			}

			var direction;

			if(body.hasClass('rtl')){
				direction = true;
			}
			else{
				direction = false;
			}

			slider.slick({
				slide: '.woocommerce-product-gallery__image',
				infinite: true,
				speed: 500,
				fade: true,
				useTransform: true,
				centerMode: true,
				centerPadding: 0,
				initialSlide: 0,
				dots: false,
				touchThreshold: 20,
				slidesToShow: 1,
				rtl: direction,
				responsive: [
					{
						breakpoint: 1025,
						settings: {
							draggable: true,
							centerPadding: 0,
							arrows: false,
							dots: true
						}
					}
				],
			});

			if(x > 1024){
				var hideNavigation = function(){
					var singleProductNav = $('nav.posts-navigation');
					if($window.scrollTop() > (y * 0.6)){
						singleProductNav.fadeIn(300);
					}
					else{
						singleProductNav.fadeOut(300);
					}
				};
				hideNavigation();

				$window.scroll(function(){
					setTimeout(function(){
						hideNavigation();
					}, 200);
				});
			}

		}

		// Product Categories

		if((body.hasClass('post-type-archive-product') || body.hasClass('tax-product_cat')) && $('.products li.product-category').length){
			var productCat = $('.products li.product-category');

			productCat.wrapAll('<section class="product-category-wrap clear"></section>');
		}

	}); // End Document Ready

	$(window).load(function(){

		// Add .product-loaded class

		var shopArchProduct = $('.woocommerce.archive ul.products li.product');

		shopArchProduct.each(function(i){
			setTimeout(function(){
				shopArchProduct.eq(i).addClass('product-loaded animate');
			}, 200 * (i+1));
		});

	}); // End Window Load

})(jQuery);
