<?php

/**
 * The header for our theme.
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package Ippo
 */

?><!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
<meta charset="<?php bloginfo( 'charset' ); ?>">
<meta name="viewport" content="width=device-width, initial-scale=1">
<link rel="profile" href="http://gmpg.org/xfn/11">
<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">

<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
<div id="page" class="site">
	<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'ippo-shop' ); ?></a>

	<?php $header_bg_color = get_theme_mod( 'ippo_bg_header_color', '#fff' ); ?>

	<header id="masthead" class="site-header" role="banner" data-bg-color="<?php echo esc_attr( $header_bg_color ); ?>">

		<div class="container">

			<div class="site-branding">

				<?php

					// Display logo and / or title
					ippo_display_logo_title();

					$description = get_bloginfo( 'description', 'display' );
					if ( $description || is_customize_preview() ) :
						printf( '<p class="site-description">%s</p>', esc_html( $description ) );
					endif;

				?>

			</div><!-- .site-branding -->

			<nav id="site-navigation" class="main-navigation" role="navigation">
				<?php
					printf( '<button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false"><i>%1$s</i>%2$s<span>%3$s</span></button>', esc_html__( 'Menu', 'ippo-shop' ), esc_html__( 'Primary Menu', 'ippo-shop' ), '&nbsp;' );
				?>

				<div class="main-nav-wrap">
					<div class="verticalize">
						<?php
							// Display nav menu
							wp_nav_menu( array( 'theme_location' => 'primary', 'menu_id' => 'primary-menu' ) );

						?>
						<?php if ( ippo_is_woocommerce_activated() ) : ?>

							<div class="main-shop-nav">
								<ul>

									<li>
										<?php if ( is_user_logged_in() ) { ?>
											<a href="<?php echo get_permalink( get_option( 'woocommerce_myaccount_page_id' ) ); ?>" title="<?php esc_html_e( 'My Account', 'ippo-shop' ); ?>"><?php esc_html_e( 'My Account','ippo-shop' ); ?></a>
										<?php }
										else { ?>
											<a href="<?php echo get_permalink( get_option( 'woocommerce_myaccount_page_id' ) ); ?>" title="<?php esc_html_e( 'Login', 'ippo-shop' ); ?>"><?php esc_html_e( 'Login', 'ippo-shop' ); ?></a>
										<?php } ?>
									</li>

									<li><?php ippo_woo_header_cart(); ?></li>

								</ul>
							</div>

						<?php endif; ?>
					</div><!-- .verticalize -->
				</div><!-- .main-nav-wrap -->
			</nav><!-- #site-navigation -->

			<!-- Search form -->
			<div class="search-wrap"><?php get_search_form(); ?><div class="search-instructions"><?php esc_html_e( 'Press Enter / Return to begin your search.', 'ippo-shop' ); ?></div></div>
			<a href="#" id="big-search-trigger">
				<span class="screen-reader-text"><?php esc_html__( 'open search form', 'ippo-shop' ); ?></span>
				<i class="icon-search"></i>
			</a>
			<a href="#" id="big-search-close">
				<span class="screen-reader-text"><?php esc_html__( 'close search form', 'ippo-shop' ); ?></span>
			</a>

			<?php if ( ippo_is_woocommerce_activated() ) : ?>
				<!-- Cart icon for touch devices -->
				<div class="cart-touch">
					<?php ippo_cart_link(); ?>
				</div>
			<?php endif; ?>

		</div><!-- .container -->

	</header><!-- #masthead -->

	<?php

		if ( is_front_page() ) :

			ippo_front_slider();

		endif;

	?>

	<?php if ( is_page_template( 'templates/template-headline.php' ) ) : ?>

		<div class="headline-content-container container">
			<div class="entry-content">
				<?php printf( wpautop( get_post_field( 'post_content', get_the_ID() ) ) ); ?>
			</div>
		</div>

	<?php endif; ?>

	<div id="content" class="site-content">

	<!-- Post categories filter -->
	<?php

		if ( ( !is_search() && is_category() || is_home() || is_page_template( 'templates/template-headline.php' ) ) && get_theme_mod( 'category_filter_setting', 1 ) ) {
			ippo_category_filter();
		}

		if ( ( !is_search() && is_archive() && is_tax( 'ct_portfolio' ) || is_page_template( 'templates/template-portfolio.php' ) ) && get_theme_mod( 'portfolio_category_filter_setting', 1 ) ) {
			ippo_category_filter( 'portfolio' );
		}

	?>
