<?php
/**
 * Ippo Theme Customizer.
 *
 * @package Ippo
 */

/**
 * Customizer Sanitization and custom function
 */
require get_template_directory() . '/inc/customizer/functions/customizer-sanitize.php';
require get_template_directory() . '/inc/customizer/functions/customizer-functions.php';

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function ippo_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	// Remove default Colors section
	$wp_customize->remove_section( 'colors' );

	$wp_customize->get_section( 'static_front_page' )->priority = 119;

	/**
	 * PANELS
	 */

	// Color Settings Panel
	$wp_customize->add_panel( 'ippo_colors_panel', array(
		'title'       => esc_html__( 'Color Settings', 'ippo-shop' ),
		'description' => esc_html__( 'For customizing theme colors', 'ippo-shop' ),
		'priority'    => 120
	) );

	// Footer Settings Panel
	$wp_customize->add_panel( 'ippo_footer_panel', array(
		'title'       => esc_html__( 'Footer Settings', 'ippo-shop' ),
		'description' => esc_html__( 'For customizing theme footer', 'ippo-shop' ),
		'priority'    => 130
	) );

	/**
	 * SECTIONS AND SETTINGS
	 */

	// Header settings
	require get_template_directory() . '/inc/customizer/settings/customizer-header.php';

	// Front page slider settings
	require get_template_directory() . '/inc/customizer/settings/customizer-front-page-slider.php';

	// Customizer Colors
	require get_template_directory() . '/inc/customizer/settings/customizer-colors.php';

	// Layout Settings
	require get_template_directory() . '/inc/customizer/settings/customizer-layout.php';

	// Paging settings
	require get_template_directory() . '/inc/customizer/settings/customizer-paging.php';

	// Instagram in footer
	require get_template_directory() . '/inc/customizer/settings/customizer-footer-instagram.php';

	// Portfolio Settings
	require get_template_directory() . '/inc/customizer/settings/customizer-portfolio.php';

	// Footer copyright Settings
	require get_template_directory() . '/inc/customizer/settings/customizer-footer.php';

	// Shop Settings
	require get_template_directory() . '/inc/customizer/settings/customizer-shop.php';

}
add_action( 'customize_register', 'ippo_customize_register' );

// if Kirki installed

if(class_exists( 'Kirki' )){

	// Google fonts
	require get_template_directory() . '/inc/customizer/settings/customizer-google-fonts.php';

}

add_action( 'wp_head', 'ippo_add_loader_styles_to_header', 100 );

function ippo_add_loader_styles_to_header() {
	?>
	<style>
		.kirki-customizer-loading-wrapper {
			background-image: none !important;
		}
	</style>
	<?php
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function ippo_customize_preview_js() {
	wp_enqueue_script( 'ippo_customizer', get_template_directory_uri() . '/assets/js/customizer.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'ippo_customize_preview_js' );

