<?php
/**
 * Sanitzation functions for Customizer settings
 *
 * @package  Ippo
 */


/**
 * Sanitize text
 */
function ippo_sanitize_text( $text ) {
    if ( '' == $text ) {
        $text = '';
    }
    return $text;
}

/**
 * Sanitize checkbox
 */
function ippo_sanitize_checkbox( $checkbox ) {
    if ( $checkbox ) {
        $checkbox = 1;
    } else {
        $checkbox = false;
    }
    return $checkbox;
}

/**
 * Sanitize selection.
 */
function ippo_sanitize_select( $selection ) {
    return $selection;
}

/**
 * Sanitize Blog layout selection
 */
function ippo_sanitize_blog_layout( $selection ) {
    if ( in_array( $selection, array( 'three-columns', 'four-columns' ) ) ) {
        return $selection;
    } else {
        return 'three-columns';
    }
}

/**
 * Sanitize slider layout selection
 */
function ippo_sanitize_slider_layout( $selection ) {
    if ( in_array( $selection, array( 'carousel', 'fullwidth' ) ) ) {
        return $selection;
    }
    else {
        return 'fullwidth';
    }
}

/**
 * Sanitize slider text position
 */
function ippo_sanitize_slider_text( $selection ) {
    if ( in_array( $selection, array( 'left-txt', 'center-txt', 'right-txt' ) ) ) {
        return $selection;
    } else {
        return 'left-txt';
    }
}

/**
 * Sanitize the value of Logo image.
 *
 * @param string $logo_image.
 * @return string $logo_image.
 */
function ippo_sanitize_image( $logo_image ) {
    return $logo_image;
}

/**
 * Sanitize colors
 */
function ippo_sanitize_color( $hex, $default = '' ) {
    if ( ippo_of_validate_hex( $hex ) ) {
        return $hex;
    }
    return $default;
}

function ippo_of_validate_hex( $hex ) {
    $hex = trim( $hex );
    /* Strip recognized prefixes. */
    if ( 0 === strpos( $hex, '#' ) ) {
        $hex = substr( $hex, 1 );
    }
    elseif ( 0 === strpos( $hex, '%23' ) ) {
        $hex = substr( $hex, 3 );
    }
    /* Regex match. */
    if ( 0 === preg_match( '/^[0-9a-fA-F]{6}$/', $hex ) ) {
        return false;
    }
    else {
        return true;
    }
}
