<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Ippo
 */

/**
 * Custom post navigation
 *
 * @since Ippo 1.0
 */
function ippo_post_navigation() {

	if ( is_single() && ( 'product' == get_post_type() ) ) {
		if ( ! get_theme_mod( 'single_product_nav', 1 ) ) {
			return;
		}
	}

	$post_navigation      = '';
	$prev_post_navigation = '';
	$next_post_navigation = '';
	$previous_post        = get_previous_post();
	$next_post            = get_next_post();

	// Previous post
	if ( !empty( $previous_post ) ) {

		if ( 'portfolio' == get_post_type() ) {

			$prev_post_category = get_the_terms( $previous_post->ID, 'ct_portfolio' );
			if ( $prev_post_category ) {
				$prev_post_category = $prev_post_category[0]->name;
			}
			$prev_text 		= esc_html__( 'Previous project', 'ippo-shop' );
			$prev_post_text = '<span class="prev-trig prev-project-trig">' . $prev_text . '</span>';

		} else {

			if ( 'post' == get_post_type() ) {
				$prev_post_category = get_the_category( $previous_post->ID );
				if ( $prev_post_category ) {
					$prev_post_category = $prev_post_category[0]->cat_name;
				}

				$prev_text = esc_html__( 'Previous article', 'ippo-shop' );
			}

			if ( 'product' == get_post_type() ) {
				$prev_post_category = get_the_terms( $previous_post->ID, 'product_cat' );

				if ( $prev_post_category ) {
					$prev_post_category = $prev_post_category[0]->name;
				}

				$prev_text = esc_html__( 'Previous product', 'ippo-shop' );
			}

			$prev_post_text = '<span class="prev-trig">' . $prev_text . '</span>';
		}

		$prev_post_navigation = $prev_post_text;
		$prev_post_navigation .= '<div class="nav-previous">';
			$prev_post_navigation .= '<span>' . $prev_text . '</span>';
			$prev_post_navigation .= '<a href="' . esc_url( get_permalink( $previous_post->ID ) ) . '"><span class="entry-meta">' . esc_html( $prev_post_category ) . '</span><span class="post-title">' . esc_html( $previous_post->post_title ) . '</span></a>';
		$prev_post_navigation .= '</div>';
	}

	// Next post
	if ( !empty( $next_post ) ) {

		if ( 'portfolio' == get_post_type() ) {
			$next_post_category = get_the_terms( $next_post->ID, 'ct_portfolio' );
			if ( $next_post_category ) {
				$next_post_category = $next_post_category[0]->name;
			}
			$next_text 		= esc_html__( 'Next project', 'ippo-shop' );
			$next_post_text = '<span class="next-trig next-project-trig">' . $next_text . '</span>';
		} else {

			if ( 'post' == get_post_type() ) {
				$next_post_category = get_the_category( $next_post->ID );
				if ( $next_post_category ) {
					$next_post_category = $next_post_category[0]->cat_name;
				}

				$next_text = esc_html__( 'Next article', 'ippo-shop' );
			}

			if ( 'product' == get_post_type() ) {
				$next_post_category = get_the_terms( $next_post->ID, 'product_cat' );

				if ( $next_post_category ) {
					$next_post_category = $next_post_category[0]->name;
				}

				$next_text = esc_html__( 'Next product', 'ippo-shop' );
			}

			$next_post_text = '<span class="next-trig">' . $next_text . '</span>';
		}

		$next_post_navigation = $next_post_text;
		$next_post_navigation .= '<div class="nav-next">';
			$next_post_navigation .= '<span>' . $next_text . '</span>';
			$next_post_navigation .= '<a href="' . esc_url( get_permalink( $next_post->ID ) ) . '"><span class="entry-meta">' . esc_html( $next_post_category ) . '</span><span class="post-title">' . esc_html( $next_post->post_title ) . '</span></a>';
		$next_post_navigation .= '</div>';
	}

	// Post navigation
	$post_navigation = $prev_post_navigation . $next_post_navigation;

	echo _navigation_markup( $post_navigation );
}

/**
 * HTML for Infinite Scroll pagination
 */
function ippo_is_pagination() {

	global $wp_query, $project_query;

	if ( is_page_template( 'templates/template-portfolio.php' ) ) {

		// Don't print empty markup if there's only one page.
		if ( $project_query->max_num_pages < 2 ) {
			return;
		}

		$wp_query = $project_query;

	} else {

		// Don't print empty markup if there's only one page.
		if ( $wp_query->max_num_pages < 2 ) {
			return;
		}

	}

	?>

	<h2 class="screen-reader-text"><?php esc_html_e( 'Posts navigation', 'ippo-shop' ); ?></h2>

	<div id="infinite-handle" class="nav-links">
		<?php if ( get_next_posts_link() ) : ?>
			<span class="nav-next">
				<?php next_posts_link( esc_html__( 'Load More', 'ippo-shop' ) ); ?>
			</span>
		<?php endif; ?>
	</div><!-- .nav-links -->

	<div id="loading-is"></div>

	<?php
}

/**
 * Displays entry header
 *
 * @since Ippo 1.0
 */
function ippo_entry_header( $type = '' ) {

	if ( ( 'link' == get_post_format() || 'quote' == get_post_format() ) && !is_single() ) {
		return;
	}

	$edit_post_link = '';

	$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
	if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
		$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
	}

	$time_string = sprintf( $time_string,
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_attr( get_the_modified_date( 'c' ) ),
		esc_html( get_the_modified_date() )
	);

	$posted_on = sprintf(
		esc_html_x( '%s', 'post date', 'ippo-shop' ),
		'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
	);

	if ( is_user_logged_in() ) {
		$edit_post_link = '<a href="' . esc_url( get_edit_post_link() ) . '"></a>';
	}

	if ( 'portfolio' == get_post_type() ) {
		$categories_list = get_the_term_list( get_the_ID(), 'ct_portfolio' );
	} else {
		$categories_list = get_the_category_list( esc_html__( '&nbsp;', 'ippo-shop' ) );
	}

	if ( is_search() ) :

		the_title( '<h2 class="entry-title"><a href="' . esc_url( get_permalink() ) . '" rel="bookmark">', '</a></h2>' );

		if ( 'product' == get_post_type() ) {

			global $product;

			$price_html = $product->get_price_html();

			echo $price_html;

		}

	endif;

	if ( !is_single() ) {

		if ( 'slide' == $type || 'portfolio' == get_post_type() ) {

			if ( 'portfolio' == get_post_type() ) {
				printf( '<div class="entry-meta"><span class="category-list">%1$s</span><span class="edit-link">%2$s</span></div>', $categories_list, $edit_post_link );
			} else {
				printf( '<div class="entry-meta"><span class="category-list">%1$s</span></div>', $categories_list );
			}

		} else {

			printf( '<div class="entry-meta"><span class="category-list">%1$s</span><span class="post-date">%2$s</span><span class="edit-link">%3$s</span></div>', $categories_list, $posted_on, $edit_post_link );
		}

	}

	if ( !is_search() ) :

		if ( !is_single() ) {
			the_title( '<h2 class="entry-title"><a href="' . esc_url( get_permalink() ) . '" rel="bookmark">', '</a></h2>' );
		}

	endif;

	if ( 'single' == $type ) {
		printf( '<div class="entry-meta"><span class="category-list">%1$s</span><span class="post-date">%2$s</span><span class="edit-link">%3$s</span></div>', $categories_list, $posted_on, $edit_post_link );
		the_title( '<h2 class="entry-title">', '</h2>' );
	}

}

if ( ! function_exists( 'ippo_entry_footer' ) ) :
/**
 * Prints HTML with meta information for the categories, tags and comments.
 */
function ippo_entry_footer() {
	// Hide category and tag text for pages.
	if ( 'post' === get_post_type() ) {
		/* translators: used between list items, there is a space after the comma */
		$categories_list = get_the_category_list( ' ' );
		if ( $categories_list && ippo_categorized_blog() ) {
			printf( '<span class="cat-links">' . esc_html__( 'Posted in %1$s', 'ippo-shop' ) . '</span>', $categories_list ); // WPCS: XSS OK.
		}

		/* translators: used between list items, there is a space after the comma */
		$tags_list = get_the_tag_list( '', ' ' );
		if ( $tags_list ) {
			printf( '<span class="tags-links"><span>&nbsp;' . esc_html__( 'and', 'ippo-shop' ) . '&nbsp;</span><span>' . esc_html__( 'Tagged %1$s', 'ippo-shop' ) . '</span></span>', $tags_list ); // WPCS: XSS OK.
		}
	}

	if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
		echo '<span class="comments-link">';
		comments_popup_link( esc_html__( 'Leave a comment', 'ippo-shop' ), esc_html__( '1 Comment', 'ippo-shop' ), esc_html__( '% Comments', 'ippo-shop' ) );
		echo '</span>';
	}
}
endif;

/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
function ippo_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'ippo_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,
			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'ippo_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so ippo_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so ippo_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in ippo_categorized_blog.
 */
function ippo_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Like, beat it. Dig?
	delete_transient( 'ippo_categories' );
}
add_action( 'edit_category', 'ippo_category_transient_flusher' );
add_action( 'save_post',     'ippo_category_transient_flusher' );

/**
 * Displays post featured image
 *
 * @since  Ippo 1.0
 */
function ippo_featured_image() {

	if ( has_post_thumbnail() ) :

		if ( is_single() ) { ?>

			<figure class="featured-image <?php echo esc_attr( ippo_get_featured_image_class() ); ?>">
				<?php the_post_thumbnail( 'ippo-single-featured-image' ); ?>
			</figure>

		<?php } else { ?>

			<?php

				$thumb_size = 'ippo-archive-featured-image';

				if ( has_tag( 'spotlight' ) ) {
					$thumb_size = 'ippo-sticky-featured-image';
				}

			?>

			<figure class="featured-image">

				<?php if ( 'image' == get_post_format() || 'portfolio' == get_post_type() ) {

					$thumb_id        = get_post_thumbnail_id();
					$thumb_url_array = wp_get_attachment_image_src( $thumb_id, 'full', true );
					$thumb_url       = $thumb_url_array[0];

				?>
					<a href="<?php echo esc_url( $thumb_url ); ?>" title="<?php echo esc_attr( get_the_title() ); ?>" class="thickbox">
						<?php the_post_thumbnail( $thumb_size, array('class' => 'skip-lazy') ); ?>
					</a>

				<?php } else { ?>

					<a href="<?php the_permalink(); ?>"><?php the_post_thumbnail( $thumb_size, array('class' => 'skip-lazy') ); ?></a>

				<?php } ?>

			</figure>

		<?php }

	else :

		return;

	endif;

}

/**
 * Displays post featured image
 */
function ippo_featured_media() {

	if ( 'gallery' == get_post_format() ) :

		$gallery_images = get_post_meta( get_the_ID(), 'ippo_repeatable', true );

		if ( $gallery_images && $gallery_images[0] !== '' ) { ?>

			<div class="entry-gallery">

				<div class="gallery gallery-size-full">

					<?php foreach( $gallery_images as $gallery_image ) : ?>

						<figure class="gallery-item">
							<a href="<?php echo esc_url( $gallery_image ); ?>" class="thickbox" rel="<?php echo esc_attr( get_the_ID() . '-post-gallery' ); ?>">
								<img src="<?php echo esc_url( $gallery_image ); ?> " alt="Gallery image">
							</a>
						</figure>

					<?php endforeach; ?>

				</div>

			</div><!-- .entry-gallery -->

		<?php } else {

			ippo_featured_image();

		}

	elseif ( 'video' == get_post_format() ) :

		$video_link = get_post_meta( get_the_ID(), 'ippo_video_link', true );

		if ( $video_link ) {

			$video_image = ippo_get_video_image( $video_link, get_the_ID(), 2 );

			?>
			<div class="entry-video">

				<?php if ( !is_single() && isset( $video_image ) ) :

						$id   = 'ippo-shop' . rand();
						$href = "#TB_inline?height=640&width=1000&inlineId=" . $id;

						$video_url = '<div id="' . $id . '" style="display:none;">' . wp_oembed_get( $video_link ) . '</div>';
						$video_url .= '<figure class="featured-image"><a class="thickbox" title="' . get_the_title() . '" href="' . $href . '">' . $video_image . '</a></figure>';

						printf( rawurldecode( $video_url ) );

					else : ?>

					<figure class="featured-image scalable-wrapper">
						<?php echo ippo_video_player( $video_link ); ?>
					</figure>

				<?php endif; ?>

			</div><!-- .entry-video -->

		<?php } else {

			ippo_featured_image();

		}

	else :

		ippo_featured_image();

	endif;

}

/**
 * Generates video player for user content post meta
 */

function ippo_video_player( $url ) {

	if ( !empty( $url ) ) {

		$key_str1    = 'youtube';
		$key_str2    = 'vimeo';
		$pos_youtube = strpos( $url, $key_str1 );
		$pos_vimeo   = strpos( $url, $key_str2 );

		if ( !empty( $pos_youtube ) ) {
			$url = str_replace( 'watch?v=', '', $url );
			$url = explode( '&', $url );
			$url = $url[0];
			$protocol = substr( $url, 0, 5 );

			if ( $protocol == "http:" ) {
				$url = str_replace( 'http://www.youtube.com/', '', $url );
			}
			if ( $protocol == "https" ) {
				$url = str_replace( 'https://www.youtube.com/', '', $url );
			}

			$iframe_video = '<iframe id="youtube-player" class="scalable-element" src="http://www.youtube.com/embed/' . $url . '?enablejsapi=1&rel=0"></iframe>';

		} elseif ( ! empty( $pos_vimeo ) ) {
			$urlParts = explode( "/", parse_url( $url, PHP_URL_PATH ) );
			$videoId  = (int) $urlParts[count($urlParts)-1 ];
			$iframe_video = '<iframe class="vimeo-video scalable-element" src="http://player.vimeo.com/video/' . $videoId . '"></iframe>';
		} else {
			$iframe_video = esc_html__( 'Video only allowes vimeo and youtube!', 'ippo-shop' );
		}

		return $iframe_video;
	}
}

/**
 * Displays post category filter
 *
 * @since Ippo 1.0
 */
function ippo_category_filter( $type = 'post' ) {

	if ( 'portfolio' == $type ) {
		$categories_list = get_terms( 'ct_portfolio' );
	} else if ( 'product' == $type ) {
		$categories_list = get_terms( 'product_cat' );
	} else {
		$categories_list = get_terms( 'category' );
	}

	if ( ! empty( $categories_list ) && ! is_wp_error( $categories_list ) ) {

		if ( ! is_home() && ( ippo_is_woocommerce_activated() && ! is_shop() ) ) {
			$term_id = get_queried_object()->term_id;
		}

		if ( ippo_is_woocommerce_activated() && is_shop() ) {
			$categories_list_display = '<ul class="category-filter">';
		} else if ( 'product' == $type ) {
			$categories_list_display = '<ul class="category-filter container">';
		} else {
			$categories_list_display = '<ul class="category-filter container">';
		}

		// Display ALL category filter link
		if ( ippo_is_woocommerce_activated() && is_tax( 'product_cat' ) ) {
			$categories_list_display .= sprintf( '<li><a href="%1$s">%2$s</a></li>', esc_url( get_permalink( wc_get_page_id( 'shop' ) ) ), esc_html__( 'All', 'ippo-shop' ) );
		} else if ( is_tax( 'ct_portfolio' ) ) {
			$categories_list_display .= sprintf( '<li><a href="%1$s">%2$s</a></li>', esc_url( get_permalink( ippo_return_portfolio_page( 'id' ) ) ), esc_html__( 'All', 'ippo-shop' ) );
		} else if ( is_category() ) {

			if ( 0 != get_option( 'page_for_posts' ) ) {
				$archive_link = get_permalink( get_option( 'page_for_posts' ) );
			} else {
				$archive_link = get_home_url();
			}

			 $categories_list_display .= sprintf( '<li><a href="%1$s">%2$s</a></li>', esc_url( $archive_link ), esc_html__( 'All', 'ippo-shop' ) );
		}

		foreach ( $categories_list as $term ) {

			if ( ! is_home() && ( ippo_is_woocommerce_activated() && ! is_shop() ) && $term->term_id == $term_id ) {
				$active_class = 'class=cat-active';
			} else {
				$active_class = '';
			}

			$categories_list_display .= '<li ' . esc_attr( $active_class ) . '><a href="' . esc_url( get_term_link( $term ) ) . '">' . $term->name . '</a></li>';

		}

		$categories_list_display .= '</ul>';

		echo $categories_list_display;

	}

}

/**
 * Dispalys Author Box under single post content
 *
 * @since  Ippo 1.0
 */
function ippo_author_box() {

	global $post;

	$user_description = get_the_author_meta( 'description', $post->post_author);

	if ( ! empty( $user_description ) ) {

		if ( 'post' == get_post_type() ) {
			$author_box = get_theme_mod( 'author_box_setting', 1 );
		} else {
			$author_box = get_theme_mod( 'portfolio_author_box_setting', 1 );
		}

		if ( $author_box ) :

			?>
				<div class="container container-small">
					<section class="author-box">
						<figure class="author-avatar">
							<?php echo get_avatar( get_the_author_meta( 'ID' ) ); ?>
						</figure>
						<div class="author-info">
							<?php printf( '<h6 class="author-name"><span>%1$s</span>%2$s</h6><p>%3$s</p>', esc_html__( 'Posted by:', 'ippo-shop' ), get_the_author_meta( 'display_name' ), get_the_author_meta( 'description' ) ); ?>
						</div>
					</section>
				</div>

			<?php

		endif;

	}

}

/**
 * Ippo custom paging function
 *
 * Creates and displays custom page numbering pagination in bottom of archives
 *
 * @since Ippo 1.0
 */
function ippo_numbers_pagination() {

	global $wp_query, $wp_rewrite, $project_query;

	if ( is_page_template( 'templates/template-portfolio.php' ) ) {
		$wp_query = $project_query;
	}

	$wp_query->query_vars['paged'] > 1 ? $current = $wp_query->query_vars['paged'] : $current = 1;

	$pagination = array(
		'base'      => @add_query_arg( 'paged', '%#%' ),
		'format'    => '',
		'total'     => $wp_query->max_num_pages,
		'current'   => $current,
		'type'      => 'list',
		'prev_next' => true,
		'prev_text' => esc_html__( 'Prev', 'ippo-shop' ),
		'next_text' => esc_html__( 'Next', 'ippo-shop' )
	);

	if ( $wp_rewrite->using_permalinks() ) {
		$pagination['base'] = user_trailingslashit( trailingslashit( remove_query_arg( 's', get_pagenum_link( 1 ) ) ) . 'page/%#%/', 'paged' );
	}

	if ( ! empty( $wp_query->query_vars['s'] ) ) {
		$pagination['add_args'] = array( 's' => get_query_var( 's' ) );
	}

	// Display pagination
	printf( '<nav class="navigation paging-navigation"><h1 class="screen-reader-text">%1$s</h1>%2$s</nav>',
		esc_html__( 'Page navigation', 'ippo-shop' ),
		paginate_links( $pagination )
	);

}

/**
 * Display the archive title based on the queried object.
 *
 * @param string $before Optional. Content to prepend to the title. Default empty.
 * @param string $after  Optional. Content to append to the title. Default empty.
 */
function ippo_archive_title( $before = '', $after = '' ) {
	if ( is_category() ) {
		$title = sprintf( esc_html__( 'All articles filed in %s', 'ippo-shop' ), '<span>' . single_cat_title( '', false ) . '</span>' );
	} elseif ( is_tag() ) {
		$title = sprintf( esc_html__( 'All articles filed in %s', 'ippo-shop' ), '<span>' . single_tag_title( '', false ) . '</span>' );
	} elseif ( is_author() ) {
		$title = sprintf( esc_html__( 'All articles filed in %s', 'ippo-shop' ), '<span class="vcard">' . get_the_author() . '</span>' );
	} elseif ( is_year() ) {
		$title = sprintf( esc_html__( 'All articles filed in %s', 'ippo-shop' ), '<span>' . get_the_date( esc_html_x( 'Y', 'yearly archives date format', 'ippo-shop' ) ) . '</span>' );
	} elseif ( is_month() ) {
		$title = sprintf( esc_html__( 'All articles filed in %s', 'ippo-shop' ), '<span>' . get_the_date( esc_html_x( 'F Y', 'monthly archives date format', 'ippo-shop' ) ) . '</span>' );
	} elseif ( is_day() ) {
		$title = sprintf( esc_html__( 'All articles filed in %s', 'ippo-shop' ), '<span>' . get_the_date( esc_html_x( 'F j, Y', 'daily archives date format', 'ippo-shop' ) ) . '</span>' );
	} elseif ( is_tax( 'post_format' ) ) {
		if ( is_tax( 'post_format', 'post-format-aside' ) ) {
			$title = esc_html_x( 'Asides', 'post format archive title', 'ippo-shop' );
		} elseif ( is_tax( 'post_format', 'post-format-gallery' ) ) {
			$title = esc_html_x( 'Galleries', 'post format archive title', 'ippo-shop' );
		} elseif ( is_tax( 'post_format', 'post-format-image' ) ) {
			$title = esc_html_x( 'Images', 'post format archive title', 'ippo-shop' );
		} elseif ( is_tax( 'post_format', 'post-format-video' ) ) {
			$title = esc_html_x( 'Videos', 'post format archive title', 'ippo-shop' );
		} elseif ( is_tax( 'post_format', 'post-format-quote' ) ) {
			$title = esc_html_x( 'Quotes', 'post format archive title', 'ippo-shop' );
		} elseif ( is_tax( 'post_format', 'post-format-link' ) ) {
			$title = esc_html_x( 'Links', 'post format archive title', 'ippo-shop' );
		} elseif ( is_tax( 'post_format', 'post-format-status' ) ) {
			$title = esc_html_x( 'Statuses', 'post format archive title', 'ippo-shop' );
		} elseif ( is_tax( 'post_format', 'post-format-audio' ) ) {
			$title = esc_html_x( 'Audio', 'post format archive title', 'ippo-shop' );
		} elseif ( is_tax( 'post_format', 'post-format-chat' ) ) {
			$title = esc_html_x( 'Chats', 'post format archive title', 'ippo-shop' );
		}
	} elseif ( is_post_type_archive() ) {
		$title = sprintf( esc_html__( '%s', 'ippo-shop' ), post_type_archive_title( '', false ) );
	} elseif ( is_tax() ) {
		$tax = get_taxonomy( get_queried_object()->taxonomy );
		/* translators: 1: Taxonomy singular name, 2: Current taxonomy term */
		$title = sprintf( esc_html__( '%1$s: %2$s', 'ippo-shop' ), $tax->labels->singular_name, '<span>' . single_term_title( '', false ) . '</span>' );
	} else {
		$title = esc_html__( 'Archives', 'ippo-shop' );
	}

	/**
	 * Filter the archive title.
	 *
	 * @param string $title Archive title to be displayed.
	 */
	$title = apply_filters( 'get_the_archive_title', $title );

	if ( ! empty( $title ) ) {
		echo $before . $title . $after;  // WPCS: XSS OK.
	}
}

/**
 * Generate and display Footer widgets
 *
 * @since Ippo 1.0
 */
function ippo_footer_widgets() {

	$footer_sidebars = array(
		'footer-widgets-1',
		'footer-widgets-2',
		'footer-widgets-3'
	);

	foreach ( $footer_sidebars as $footer_sidebar ) {

		if ( is_active_sidebar( $footer_sidebar ) ) { ?>

			<div class="col-lg-4 col-sm-6 widget-area">
				<?php dynamic_sidebar( $footer_sidebar ); ?>
			</div>

		<?php

		}

	}

}

/**
 * Get custom logo image source
 */

add_filter( 'get_custom_logo', 'ippo_get_custom_logo' );
function ippo_get_custom_logo() {
	$custom_logo_id = get_theme_mod( 'custom_logo' );
	$html = sprintf( '%1$s',
			wp_get_attachment_image( $custom_logo_id, 'full', false, array(
				'class' => 'custom-logo',
			) )
		);
	return $html;
}

/**
 * Dispaly header logo
 */
function ippo_display_logo_title() {

	$logo_class   = 'standard-logo';
	$headline_class = 'screen-reader-text';

	if ( has_custom_logo() ) {
		$logo = get_custom_logo();
	}

	if ( isset( $logo ) ) :
		// Display logo
		printf( '<a href="%1$s" rel="home" class="%2$s">%3$s</a>', esc_url( home_url( '/' ) ), $logo_class, $logo );
	else :
		$headline_class = '';
	endif;

	if ( '' != get_bloginfo( 'name' ) ) {
		if ( is_front_page() && is_home() ) : ?>
			<h1 class="site-title <?php echo esc_attr( $headline_class ); ?>"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
		<?php else : ?>
			<p class="site-title <?php echo esc_attr( $headline_class ); ?>"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
		<?php endif;
	}

}

/**
 * Displays related posts on single post page
 */
function ippo_related_posts() {

	$post_id        = get_the_ID();
	$posts_per_page = 3;
	$categories     = get_the_terms( $post_id, 'category' );
	$cats           = array();

	if ( ! empty( $categories ) ) {
		foreach ( $categories as $category ) {
			$cats[] = $category->term_id;
		}
		$cats = implode( ',', $cats );

		$args = array(
			'cat'            => $cats,
			'post_type'      => 'post',
			'post_status'    => 'publish',
			'posts_per_page' => $posts_per_page,
			'post__not_in'   => array( $post_id )
		);

		// Get related posts
		$related_query = new WP_Query( $args );

		// Related posts Loop
		if ( $related_query->have_posts() ) : ?>

			<div id="jp-relatedposts" class="jp-relatedposts">

				<?php printf( '<h3 class="jp-relatedposts-headline">%s</h3>', esc_html__( 'Related Articles', 'ippo-shop' ) ); ?>

				<div class="jp-relatedposts-items jp-relatedposts-items-visual">

					<?php

						while( $related_query->have_posts() ) : $related_query->the_post();

							get_template_part( 'templates/template-parts/content', 'related' );

						endwhile;

						wp_reset_postdata();

					?>

				</div>
				<!-- .jp-relatedposts-items -->

			</div>
			<!-- .jp-relatedposts -->

			<?php
		endif;

	}
	else {
		return;
	}
}


/**
 * Front Page Slider
 */
function ippo_front_slider() {

	$front_slider    = get_theme_mod( 'front_page_slider_enable', 1 );
	$slides_number   = get_theme_mod( 'front_page_slider_slides', 5 );
	$slides_category = get_theme_mod( 'front_page_slider_category', 'default' );

	if ( $front_slider ) :

		if ( 'default' != $slides_category ) {

			$args = array(
				'post_type'      => 'slide',
				'posts_per_page' => $slides_number,
				'tax_query'      => array(
					'relation'   => 'AND',
						array(
							'taxonomy' => 'ct_slider',
							'field'    => 'slug',
							'terms'    => array( $slides_category ),
							'operator' => 'IN'
						),
				)
			);

		}
		else {

			$args = array(
				'post_type'      => 'slide',
				'posts_per_page' => $slides_number,
			);

		}

		$front_slides = new WP_Query( $args );

		if ( $front_slides->have_posts() ) : ?>

			<div class="featured-slider-wrap">
				<article class="featured-slider">

					<?php

						while ( $front_slides->have_posts() ) : $front_slides->the_post();

							$slide_desc      = get_post_meta( get_the_ID(), 'ippo_slide_desc', true );
							$slide_link      = get_post_meta( get_the_ID(), 'ippo_slide_link', true );
							$slide_txt_align = get_post_meta( get_the_ID(), 'ippo_slider_text_alignment', true );

					?>

						<section>
							<figure class="featured-image" style="background-image: url( <?php the_post_thumbnail_url( 'full' ); ?> )"></figure>
							<div class="slide-text <?php echo esc_attr( $slide_txt_align ); ?> ">

								<?php if ( '' != $slide_link ) { ?>

									<a href="<?php echo esc_url( $slide_link ); ?>">
										<?php the_title( '<h2 class="fp-slider-headline-'. get_the_ID() .'">', '</h2>' ); ?>
									</a>

								<?php } else { ?>

									<?php the_title( '<h2 class="fp-slider-headline-'. get_the_ID() .'">', '</h2>' ); ?>

								<?php } ?>

								<?php

									printf( '<aside class="fp-slider-text-'. get_the_ID() .'">%s</aside>', wpautop( $slide_desc ) );

								?>

							</div>
						</section>

					<?php endwhile; ?>

				</article>
			</div>

		<?php

		else :

			return;

		endif;

		wp_reset_postdata();

	endif; // if slider is enabled

}

function ippo_front_slider_style() {

	$front_slider    = get_theme_mod( 'front_page_slider_enable', 1 );
	$slides_number   = get_theme_mod( 'front_page_slider_slides', 5 );
	$slides_category = get_theme_mod( 'front_page_slider_category', 'default' );

	if ( $front_slider ) :

		if ( 'default' != $slides_category ) {

			$args = array(
				'post_type'      => 'slide',
				'posts_per_page' => $slides_number,
				'tax_query'      => array(
					'relation'   => 'AND',
						array(
							'taxonomy' => 'ct_slider',
							'field'    => 'slug',
							'terms'    => array( $slides_category ),
							'operator' => 'IN'
						),
				)
			);

		}
		else {

			$args = array(
				'post_type'      => 'slide',
				'posts_per_page' => $slides_number,
			);

		}

		$front_slides = new WP_Query( $args );

		if ( $front_slides->have_posts() ) :

			$slider_style = ''; ?>

			<?php

				while ( $front_slides->have_posts() ) : $front_slides->the_post();

					// Title & Text
					$slide_h_font      = get_post_meta( get_the_ID(), 'ippo_slide_headline_size', true );
					if (!is_numeric($slide_h_font) ) {
						$slide_h_font = 50;
					}
					$slide_h_font_size = $slide_h_font / 18;
					$slide_h_color     = get_post_meta( get_the_ID(), 'ippo_headline_color', true );
					$slide_txt_color   = get_post_meta( get_the_ID(), 'ippo_text_color', true );

					// Slider Colors
					$slide_h_color       = get_post_meta( get_the_ID(), 'ippo_headline_color', true );
					$slide_h_hover_color = get_post_meta( get_the_ID(), 'ippo_headline_hover_color', true );

				$slider_style .= '

					/* FRONT PAGE TEMPLATE */
					.fp-slider-headline-'.get_the_ID().' {
						color: '.esc_attr( $slide_h_color ).';
						-webkit-transition: color .3s;
						-moz-transition: color .3s;
						-ms-transition: color .3s;
						-o-transition: color .3s;
						transition: color .3s;
						font-size: '.esc_attr( $slide_h_font_size ).'rem !important;
					}

					.fp-slider-headline-'.get_the_ID().':hover {
						color: '.esc_attr( $slide_h_hover_color ).';
					}

					.fp-slider-text-'.get_the_ID().' {
						color: '.esc_attr( $slide_txt_color ).';
					}

				'

			;  ?>

			<?php

				endwhile;

				wp_reset_postdata();

				return $slider_style;

			endif; ?>

		<?php

	endif; // if slider is enabled

}
