<?php
/**
 * WooCommerce Shop specific functions
 *
 * @package Ippo
 */

/**
 * Remove ordering action from shop page
 */
remove_action( 'woocommerce_before_shop_loop', 'woocommerce_catalog_ordering', 30 );
remove_action( 'woocommerce_before_shop_loop', 'woocommerce_result_count', 20 );


/**
 * Add Cart Items Count
 *
 * @since  Ippo 1.0
 */
if ( ! function_exists( 'ippo_cart_link' ) ) {

	function ippo_cart_link() { ?>

		<a class="cart-contents" href="<?php echo esc_url( WC()->cart->get_cart_url() ); ?>" title="<?php esc_html_e( 'View your order summary', 'ippo-shop' ); ?>">
			<span class="count"><?php echo WC()->cart->get_cart_contents_count(); ?></span><?php echo WC()->cart->get_cart_total(); ?>
			<i class="icon-cart"></i>
		</a>

<?php

	}
}

/**
 * Refreshes mini cart after ajax add to cart
 */
function ippo_header_add_to_cart_fragment( $fragments ) {
	ob_start();
	?>

		<a class="cart-contents" href="<?php echo esc_url( WC()->cart->get_cart_url() ); ?>" title="<?php esc_html_e( 'View your order summary', 'ippo-shop' ); ?>">
			<span class="count"><?php echo WC()->cart->get_cart_contents_count(); ?></span><?php echo WC()->cart->get_cart_total(); ?>
			<i class="icon-cart"></i>
		</a>
	</a>

	<?php

	$fragments['a.cart-contents'] = ob_get_clean();

	return $fragments;
}
add_filter( 'woocommerce_add_to_cart_fragments', 'ippo_header_add_to_cart_fragment' );

/**
 * Display Header Mini Cart
 *
 * @since  Ippo 1.0
 * @uses  ippo_is_woocommerce_activated() check if WooCommerce is activated
 */
if ( ! function_exists( 'ippo_woo_header_cart' ) ) {

	function ippo_woo_header_cart() {

		if ( ippo_is_woocommerce_activated() ) {

			if ( is_cart() ) {
				$class = 'current-menu-item';
			} else {
				$class = '';
			}

		?>

		<ul class="header-cart menu">
			<li class="<?php echo esc_attr( $class ); ?>">
				<?php ippo_cart_link(); ?>
			</li>
			<li class="cart-widget__container">
				<div class="cart-widget__wrapper">
					<div class="cart-widget">
						<?php the_widget( 'WC_Widget_Cart', 'title=' ); ?>
					</div>
				</div>
			</li>
		</ul>

		<?php

		}
	}

}

/**
 * Remove parenthesis from review tabs on single product page
 */
function ippo_remove_parenthesis_woo_products( $content ) {
	$content = str_replace( '(', '', $content );
	$content = str_replace( ')', '', $content );

	return $content;
}
add_filter( 'woocommerce_product_reviews_tab_title', 'ippo_remove_parenthesis_woo_products' );
add_filter( 'woocommerce_product_get_rating_html', 'ippo_remove_parenthesis_woo_products' );

/**
 * Display sharing icons on single product page
 */
function ippo_woo_social_share() {

	// Get Customizer settings
	$product_social_share    = get_theme_mod( 'product_social_enable', 1 );
	$product_facebook_share  = get_theme_mod( 'product_social_facebook', 1 );
	$product_twitter_share   = get_theme_mod( 'product_social_twitter', 1 );
	$product_tumblr_share    = get_theme_mod( 'product_social_tumblr', 1 );
	$product_pinterest_share = get_theme_mod( 'product_social_pinterest', 1 );
	$product_email_share     = get_theme_mod( 'product_social_email', 1 );
	$pin_image               = wp_get_attachment_url( get_post_thumbnail_id( get_the_ID() ) );
	$link                    = get_permalink();
	$title                   = get_the_title();

	// Display product social share
	if ( $product_social_share ) :

		if ( is_single() ) {

			echo '<div class="product-share-wrap">';

			// Display share link
			printf( '<button class="share-trig"><span>%s</span></button>', esc_html__( 'Share', 'ippo-shop' ) );

				echo '<div class="product-share-box">';

					// Facebook
					if ( $product_pinterest_share ) {
						$furl = 'https://www.facebook.com/sharer/sharer.php?u=' . $link;
						printf( '<a href="%s"><i class="icon-facebook"></i></a>', esc_url( $furl ) );
					}

					// Twitter
					if ( $product_twitter_share ) {
						$turl = 'https://twitter.com/home?status=Check%20out%20this%20article:%20' . $title . '%20-%20' . $link;
						printf( '<a href="%s"><i class="icon-twitter"></i></a>', esc_url( $turl ) );
					}

					// Tumblr
					if ( $product_twitter_share ) {
						$tburl = 'http://www.tumblr.com/share/link?url='. $link .'&description=' . get_the_excerpt();
						printf( '<a href="%s"><i class="icon-tumblr"></i></a>', esc_url( $tburl ) );
					}

					// Pinterest
					if ( $product_pinterest_share ) {
						$purl = 'https://pinterest.com/pin/create/button/?url=' . $link . '&media=' . $pin_image . '&description=' . $title;
						printf( '<a href="%s"><i class="icon-pinterest"></i></a>', esc_url( $purl ) );
					}

					// Email
					if ( $product_email_share ) {
						$eurl = 'mailto:?Subject=' . $title . '&Body=I%20saw%20this%20and%20thought%20of%20you!%20' . $link;
						printf( '<a href="%s"><i class="icon-mail"></i></a>', esc_url( $eurl ) );
					}

				echo '</div>'; // end product-share-box

			echo '</div>'; // end product-share-wrap

		}

	endif;

}
add_action( 'woocommerce_after_add_to_cart_form', 'ippo_woo_social_share' );

/**
 * Display first gallery image next to thumbnail
 */
function ippo_display_gallery_image() {

	global $product;

	// Display first image of product gallery
	$attachment_ids = $product->get_gallery_image_ids();

	if ( ! empty( $attachment_ids ) ) {
		$image_link = wp_get_attachment_url( $attachment_ids[0] );
		printf( '<img src="%1s" alt="%2s">', $image_link, esc_html__( 'Product Image', 'ippo-shop' ) );
	}
}

/**
 * Add action to display first gallery thumbnail image
 */
add_action( 'woocommerce_before_shop_loop_item_title', 'ippo_display_gallery_image', 11 );

/**
 * Add product navigation to single product
 */
add_action( 'woocommerce_after_single_product_summary', 'ippo_post_navigation', 5 );

/**
 * Don't display heading on shop poge
 */
function ippo_remove_heading_shop() {
	return false;
}
add_filter( 'woocommerce_show_page_title', 'ippo_remove_heading_shop' );

/**
 * Remove Woocommerce column selector
 */
function ippo_woo_customize_register( $wp_customize ) {
	// Remove Woocommerce colums selector
	$wp_customize->remove_control('woocommerce_catalog_columns');

	// Remove Woocommerce rows selector
	$wp_customize->remove_control('woocommerce_catalog_rows');

	// Change Woocommerce default thumbnail width
	$wp_customize->get_setting( 'woocommerce_thumbnail_image_width' )->default = '431';

	// Change Woocommerce default Single product image width
	$wp_customize->get_setting( 'woocommerce_single_image_width' )->default = '1024';
}
add_action( 'customize_register', 'ippo_woo_customize_register' );
