<?php
/**
 * The main template file.
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package Ippo
 */

$paging_type = get_theme_mod( 'paging_setting', 'infinite-scroll' );

get_header();

?>

	<div class="container main-container">

		<div class="row">
			<div id="primary" class="content-area <?php ippo_content_classes(); ?>">
				<main id="main" class="site-main" role="main">

				<?php

					if ( have_posts() ) {

						if (is_home() && !is_front_page()) : ?>

							<header>
								<h1 class="page-title screen-reader-text"><?php single_post_title(); ?></h1>
							</header>

						<?php endif; ?>

						<div class="row">
							<div class="masonry" id="post-load">

								<div class="<?php ippo_grid_sizer_class(); ?>"></div>

								<?php

								while (have_posts()) : the_post();

									get_template_part('templates/template-parts/content', get_post_format());

								endwhile;

								if ('infinite-scroll' == $paging_type) {
									ippo_is_pagination();
								}

								?>

							</div><!-- .masonry -->
						</div><!-- .row -->

						<?php

						if ('infinite-scroll' != $paging_type) {
							// Archives numbered paging
							ippo_numbers_pagination();
						}

					} else {

						get_template_part('templates/template-parts/content', 'none');

					}

				?>

				</main><!-- #main -->
			</div><!-- #primary -->

			<?php get_sidebar(); ?>
		</div><!-- .row -->
	</div><!-- .container -->

<?php
get_footer();
