<?php
/**
 * Template Name: Portfolio template
 *
 * @package Ippo
 */
get_header();

$paging_type = get_theme_mod( 'paging_setting', 'infinite-scroll' );

?>

	<div class="container main-container">
		<div id="primary" class="content-area">
			<main id="main" class="site-main" role="main">

				<?php

					if ( get_query_var( 'paged' ) ) {
						$paged = get_query_var( 'paged' );
					}
					elseif ( get_query_var( 'page' ) ) {
						$paged = get_query_var( 'page' );
					}
					else {
						$paged = 1;
					}

					$posts_per_page = get_theme_mod( 'projects_per_page', 9 );

					$args = array(
						'post_type'      => 'portfolio',
						'posts_per_page' => $posts_per_page,
						'paged'			 => $paged
					);

					$project_query = new WP_Query ( $args );

					if ( post_type_exists( 'portfolio' ) && $project_query->have_posts() ) :
					?>

						<div class="portfolio-wrapper row">
							<div class="masonry" id="post-load">

								<div class="<?php ippo_grid_sizer_class(); ?>"></div>

								<?php

									while ( $project_query->have_posts() ) : $project_query->the_post();

										get_template_part( 'templates/template-parts/content', 'portfolio' );

									endwhile;

									if ( 'infinite-scroll' == $paging_type ) {
										ippo_is_pagination();
									}

								?>

							</div><!-- .masonry -->
						</div><!-- .row -->

						<?php

							if ( 'infinite-scroll' != $paging_type ) {
								// Archives numbered paging
								ippo_numbers_pagination();
							}

							wp_reset_postdata();
						?>

					<?php else : ?>

						<section class="no-results not-found">

							<header class="page-header">
								<h1 class="page-title"><?php esc_html_e( 'Nothing Found', 'ippo-shop' ); ?></h1>
							</header>
							<div class="page-content">
								<?php if ( current_user_can( 'publish_posts' ) ) : ?>

									<p><?php printf( wp_kses( __( 'Ready to publish your first project? <a href="%1$s">Get started here</a>.', 'ippo-shop' ), array( 'a' => array( 'href' => array() ) ) ), esc_url( admin_url( 'post-new.php?post_type=portfolio' ) ) ); ?></p>

								<?php else : ?>

									<p><?php esc_html_e( 'It seems we can&rsquo;t find what you&rsquo;re looking for. Perhaps searching can help.', 'ippo-shop' ); ?></p>
									<?php get_search_form(); ?>
									<div class="search-instructions"><?php esc_html_e( 'Press Enter / Return to begin your search.', 'ippo-shop' ); ?></div>

								<?php endif; ?>
							</div>

						</section>

					<?php endif; ?>

			</main>
		</div>
	</div><!-- .container -->

<?php get_footer(); ?>
